==> nextcloud-14.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/pt_BR.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "Editar comentário",
    "Delete comment" : "Excluir comentário",
    "New comment …" : "Novo comentário",
    "Post" : "Postar",
    "Cancel" : "Cancelar",
    "[Deleted user]" : "[Usuário excluído]",
    "Comments" : "Comentários",
    "No comments yet, start the conversation!" : "Nenhum comentário ainda, inicie uma conversa!",
    "More comments …" : "Mais comentários...",
    "Save" : "Salvar",
    "Allowed characters {count} of {max}" : "{count} de {max} caracteres permitidos",
    "Error occurred while retrieving comment with ID {id}" : "Erro ao recuperar comentário com a ID {id}",
    "Error occurred while updating comment with id {id}" : "Ocorreu um erro durante a atualização do comentário com id {id}",
    "Error occurred while posting comment" : "Ocorreu um erro ao postar o  comentário",
    "_%n unread comment_::_%n unread comments_" : ["%n comentários não lidos","%n comentários não lidos"],
    "Comment" : "Comentar",
    "You commented" : "Você comentou",
    "%1$s commented" : "%1$s comentou",
    "{author} commented" : "{author} comentou",
    "You commented on %1$s" : "Você comentou em %1$s",
    "You commented on {file}" : "Você comentou sobre {file}",
    "%1$s commented on %2$s" : "%1$s comentaram em %2$s",
    "{author} commented on {file}" : "{author} comentou em {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentários</strong> para arquivos",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Você foi mencionado em \"{file}\", em um comentário por um usuário que já foi excluído",
    "{user} mentioned you in a comment on “{file}”" : "{user} mencionou você em um comentário sobre “{file}”",
    "Files app plugin to add comments to files" : "Complemento do aplicativo Files para adicionar comentários",
    "Unknown user" : "Usuário desconhecido",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Um usuário excluído (agora) mencionou você em um comentário sobre “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Um usuário (now)  recém excluído mencionou você em um comentário sobre “{file}”",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s mencionou você em um comentário sobre “%2$s”",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Você foi mencionado em \"\", “%s”, em um comentário por um usuário que já foi excluído"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/pt_BR.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "Editar comentário",
    "Delete comment" : "Excluir comentário",
    "New comment …" : "Novo comentário",
    "Post" : "Postar",
    "Cancel" : "Cancelar",
    "[Deleted user]" : "[Usuário excluído]",
    "Comments" : "Comentários",
    "No comments yet, start the conversation!" : "Nenhum comentário ainda, inicie uma conversa!",
    "More comments …" : "Mais comentários...",
    "Save" : "Salvar",
    "Allowed characters {count} of {max}" : "{count} de {max} caracteres permitidos",
    "Error occurred while retrieving comment with ID {id}" : "Erro ao recuperar comentário com a ID {id}",
    "Error occurred while updating comment with id {id}" : "Ocorreu um erro durante a atualização do comentário com id {id}",
    "Error occurred while posting comment" : "Ocorreu um erro ao postar o  comentário",
    "_%n unread comment_::_%n unread comments_" : ["%n comentários não lidos","%n comentários não lidos"],
    "Comment" : "Comentar",
    "You commented" : "Você comentou",
    "%1$s commented" : "%1$s comentou",
    "{author} commented" : "{author} comentou",
    "You commented on %1$s" : "Você comentou em %1$s",
    "You commented on {file}" : "Você comentou sobre {file}",
    "%1$s commented on %2$s" : "%1$s comentaram em %2$s",
    "{author} commented on {file}" : "{author} comentou em {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentários</strong> para arquivos",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Você foi mencionado em \"{file}\", em um comentário por um usuário que já foi excluído",
    "{user} mentioned you in a comment on “{file}”" : "{user} mencionou você em um comentário sobre “{file}”",
    "Files app plugin to add comments to files" : "Complemento do aplicativo Files para adicionar comentários",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Você foi mencionado em \"\", “%s”, em um comentário por um usuário que já foi excluído",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s mencionou você em um comentário sobre “%2$s”"
},
"nplurals=2; plural=(n > 1);");
